#
# spec file for package namecoin-core
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.
#

%if 0%{?rhel} >= 5 && 0%{?rhel} < 7
%global use_systemd 0
%else
%global use_systemd 1
%endif

Name:		namecoin-core
Version:	0.19.0.1
Release:	1%{dist}
License:	MIT
Summary:	P2P digital currency
Url:		https://namecoin.org/
Group:		Productivity/Networking/Other
Source:		https://github.com/namecoin/%{name}/archive/nc%{version}.tar.gz
Source5:	namecoin.service
# This commit fixes build on CentOS 7 with GCC 4.8.5
Patch0:		namecoin-funcsig.patch
%if %{use_systemd}
# systemd macros are not defined unless systemd is present
BuildRequires: systemd
Requires: systemd
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
%else
Requires:	/sbin/chkconfig 
%endif
Requires:	logrotate 
Requires(pre):	shadow-utils 
BuildRequires:	autoconf automake shtool libtool protobuf-devel libevent-devel
BuildRequires:	boost-devel libcurl-devel
%if 0%{?fedora} > 0
BuildRequires:	miniupnpc-devel
BuildRequires:	qrencode-devel
BuildRequires:	libdb4-cxx-devel
BuildRequires:	jansson-devel
%else
BuildRequires:	gcc-c++
BuildRequires:	db4-devel
#BuildRequires:	libjansson-devel-static
BuildRequires:	jansson-devel
%endif
#BuildRequires:	libopenssl-ecc-devel
BuildRequires:	db4-cxx-devel
BuildRequires:	miniupnpc-devel
BuildRequires:	qrencode-devel
BuildRequires:	openssl-devel
BuildRequires:	qt5-qttools-devel
BuildRequires:	python3
BuildRoot:	%{_tmppath}/%{name}-%{version}-build

%description
Namecoin-core is a decentralized key/value registration and transfer system
based on Bitcoin-core technology.

It can be used for multiple purposes, for example a secure and censorship
resistant replacement for DNS.

Ownership of a name is based on ownership of a coin, which is in turn based
on public key cryptography. The namecoin network reaches consensus every
few minutes as to which names have been reserved or updated.

This package contains the daemon only.

%package gui
Summary:	GUI application for Namecoin
Group:		Productivity/Networking/Other

%description gui
Namecoin-core is a decentralized key/value registration and transfer system
based on Bitcoin-core technology.

This package contains the gui application and desktop integration.

%package devel
Summary:	Namecoin consensus libraries
Group:		Development/Libraries

%description devel
Namecoin-core is a decentralized key/value registration and transfer system
based on Bitcoin-core technology.

This package contains the files needed to use libnamecoinconsensus. 

%prep
%setup -q -n %{name}-nc%{version}
%patch0 -p1 -b .funcsig
./autogen.sh

%build
%{configure}
%{make_build}

%install
%{make_install}
mkdir -p %{buildroot}%{_unitdir}
install -pm 644 %{SOURCE5} %{buildroot}%{_unitdir}
#cd %{buildroot}%{_mandir}/man1
#mv bitcoin-cli.1 namecoin-cli.1
#mv bitcoin-tx.1 namecoin-tx.1
#mv bitcoin-qt.1 namecoin-qt.1
#mv bitcoind.1 namecoind.1
#cd -
# logrotate config to delete old logs
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d
cat >%{buildroot}%{_sysconfdir}/logrotate.d/%{name} <<EOF
%{_sharedstatedir}/%{name}/.namecoin/debug.log {
    missingok
    copytruncate
    compress
    weekly
}
EOF


%check
make check

%files
%license COPYING
%doc *.md doc TODO Changes
%{_bindir}/bench_namecoin
%{_bindir}/namecoin-cli
%{_bindir}/namecoin-tx
%{_bindir}/namecoin-wallet
%{_bindir}/namecoind
%{_bindir}/test_namecoin
%{_unitdir}/namecoin.service
%{_sysconfdir}/logrotate.d/%{name}
%{_libdir}/libnamecoinconsensus.so.0
%{_libdir}/libnamecoinconsensus.so.0.0.0
%{_mandir}/man1/namecoin-cli.1.gz
%{_mandir}/man1/namecoin-tx.1.gz
%{_mandir}/man1/namecoin-wallet.1.gz
%{_mandir}/man1/namecoind.1.gz

%files devel
%{_includedir}/namecoinconsensus.h
%{_libdir}/libnamecoinconsensus.a
%{_libdir}/libnamecoinconsensus.la
%{_libdir}/libnamecoinconsensus.so
%{_libdir}/pkgconfig/libnamecoinconsensus.pc

%files gui
%{_mandir}/man1/namecoin-qt.1.gz
%{_bindir}/test_namecoin-qt
%{_bindir}/namecoin-qt

%pre
getent group namecoin > /dev/null || groupadd -r namecoin
getent passwd namecoin > /dev/null || /usr/sbin/useradd -u 489 -g namecoin \
        -c "Decentralized blockchain currency and name registration" \
        -r -d %{_sharedstatedir}/%{name} -s /sbin/nologin namecoin
exit 0

%if %{use_systemd}

%post
%systemd_post namecoin.service

%postun
%systemd_postun_with_restart namecoin.service

%preun
%systemd_preun namecoin.service

%else

%post
/sbin/chkconfig --add namecoind

%endif

%changelog
* Sat Oct 12 2019 Stuart Gathman <stuart@gathman.org> 0.18.1-1
- New upstream release

* Mon Dec  3 2018 Stuart Gathman <stuart@gathman.org> 0.17.0-1
- New upstream release

* Tue Oct  2 2018 Stuart Gathman <stuart@gathman.org> 0.16.1-3
- Add logrotate

* Mon Oct  1 2018 Stuart Gathman <stuart@gathman.org> 0.16.1-2
- Rename man pages to not conflict with bitcoin

* Mon Jul 23 2018 Stuart Gathman <stuart@gathman.org> 0.16.1-1
- EL7 and systemd support - initial rpm

